@@ -20,11 +20,9 @@
 #include "dbusinterface.h"
 #include "global.h"
 
-#include <QDBusConnection>
-#include <QList>
-#include <QUrl>
 #include <KPropertiesDialog>
-#include <KRun>
+
+#include <QDBusConnection>
 
 DBusInterface::DBusInterface() :
     QObject()
@@ -41,7 +39,7 @@ void DBusInterface::ShowFolders(const QStringList& uriList, const QString& start
     if (urls.isEmpty()) {
         return;
     }
-    KRun::run(QStringLiteral("dolphin %U"), urls, nullptr);
+    Dolphin::openNewWindow(urls);
 }
 
 void DBusInterface::ShowItems(const QStringList& uriList, const QString& startUpId)
@@ -51,7 +49,7 @@ void DBusInterface::ShowItems(const QStringList& uriList, const QString& startUp
     if (urls.isEmpty()) {
         return;
     }
-    KRun::run(QStringLiteral("dolphin --select %U"), urls, nullptr);
+    Dolphin::openNewWindow(urls, nullptr, Dolphin::OpenNewWindowFlag::Select);
 }
 
 void DBusInterface::ShowItemProperties(const QStringList& uriList, const QString& startUpId)
