@@ -19,18 +19,18 @@
 
 #include "kcmdolphinnavigation.h"
 
+#include "settings/navigation/navigationsettingspage.h"
+
 #include <KPluginFactory>
 #include <KPluginLoader>
 
-#include <settings/navigation/navigationsettingspage.h>
-
 #include <QVBoxLayout>
 
 K_PLUGIN_FACTORY(KCMDolphinNavigationConfigFactory, registerPlugin<DolphinNavigationConfigModule>(QStringLiteral("dolphinnavigation"));)
 
 DolphinNavigationConfigModule::DolphinNavigationConfigModule(QWidget* parent, const QVariantList& args) :
     KCModule(parent),
-    m_navigation(0)
+    m_navigation(nullptr)
 {
     Q_UNUSED(args);
 
@@ -41,7 +41,7 @@ DolphinNavigationConfigModule::DolphinNavigationConfigModule(QWidget* parent, co
 
     m_navigation = new NavigationSettingsPage(this);
     connect(m_navigation, &NavigationSettingsPage::changed, this, static_cast<void(DolphinNavigationConfigModule::*)()>(&DolphinNavigationConfigModule::changed));
-    topLayout->addWidget(m_navigation, 0, 0);
+    topLayout->addWidget(m_navigation, 0, nullptr);
 }
 
 DolphinNavigationConfigModule::~DolphinNavigationConfigModule()
